==> XIV_host_attach-1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/platform/iscsi/linux_iscsi/iscsid_conf/__init__.py <==
#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging
import definitions

from iscsi.classes import ConfigFileReader, ConfigFileWriter, IIscsidConf, \
    IConfigFile

class ConfigFileLinuxIscsi(IConfigFile):
    def __init__(self, filepath, backup_path):
        self.discovery_addresses = []
        self.filepath = filepath
        self.backup_path = backup_path
        self.settings = {}
        self.reader = ConfigFileReader(self.filepath)
        self.read()
    
    def analyze(self):
        for line in self.reader.config_lines:
            (name, value) = self.split_n_strip_line(line)
            logging.debug('found %s=%s' % (name, value))
            if name == 'DiscoveryAddress':
                self.add_discovery_address(value)
            else:
                self.add_setting(name, value)

    def add_discovery_address(self, value):
        if not self.discovery_addresses.__contains__(value):
            self.discovery_addresses.append(value)

    def remove_discovery_address(self, value):
        if self.discovery_addresses.__contains__(value):
            self.discovery_addresses.remove(value)
    
    def write_to_file(self, filepath=''):
        if filepath == '':
            filepath = self.filepath 
        writer = ConfigFileWriter(filepath, self.settings, self.discovery_addresses)
        return writer.write_to_file()

    def is_empty(self):
        if len(self.settings) == 0 and len(self.discovery_addresses) == 0:
            return True
        return False
        
class IscsidConfLinuxIscsi(IIscsidConf):
    def __init__(self, backup_path):
        self.backup_path = backup_path
        self.source_file = definitions.ISCSI_CONF_SOURCE
        self.set_dest_filename()
        self.load_config()

    def load_config(self):
        self.source_config = ConfigFileLinuxIscsi(\
            self.source_file, self.backup_path)
        self.dest_config = ConfigFileLinuxIscsi(\
            self.dest_filename, self.backup_path)
        self.source_config.read()
        self.dest_config.read()

    def set_dest_filename(self):
        self.dest_filename = '/etc/iscsi.conf'

==> XIV_host_attach-1.1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/platform/iscsi/linux_iscsi/iscsid_conf/__init__.py <==
#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging
import definitions

from iscsi.classes import ConfigFileReader, ConfigFileWriter, IIscsidConf, \
    IConfigFile

class ConfigFileWriterLinuxIscsi(ConfigFileWriter):
    """iscsid.conf configuration handler (Old Linux-iSCSI)"""
    def __init__(self, filepath, settings = {}, discovery_addresses=[]):
        ConfigFileWriter.__init__(self, filepath, settings)
        self.discovery_addresses = discovery_addresses

    def append_settings(self):
        super.append_settings(self)
        for (name, value) in self.settings.iteritems():
            self.lines.append('%s=%s' % (name, value))

    def append_settings(self):
        for (name, value) in self.settings.iteritems():
            # NOTE: Unlike open_iscsi we don't use spaces here between
            # key & value, there might be a good reason for it
            self.lines.append('%s=%s' % (name, value))

        self.append_discovery_addresses()

    def append_discovery_addresses(self):
        for address in self.discovery_addresses:
            self.lines.append('DiscoveryAddress=%s' % address)

class ConfigFileLinuxIscsi(IConfigFile):
    def __init__(self, filepath, backup_path):
        self.discovery_addresses = []
        self.filepath = filepath
        self.backup_path = backup_path
        self.settings = {}
        self.reader = ConfigFileReader(self.filepath)
        self.read()
    
    def analyze(self):
        for line in self.reader.config_lines:
            (name, value) = self.split_n_strip_line(line)
            logging.debug('found %s=%s' % (name, value))
            if name == 'DiscoveryAddress':
                self.add_discovery_address(value)
            else:
                self.add_setting(name, value)

    def add_discovery_address(self, value):
        if not self.discovery_addresses.__contains__(value):
            self.discovery_addresses.append(value)

    def remove_discovery_address(self, value):
        if self.discovery_addresses.__contains__(value):
            self.discovery_addresses.remove(value)
    
    def write_to_file(self, filepath=''):
        if filepath == '':
            filepath = self.filepath 
        writer = ConfigFileWriterLinuxIscsi(filepath, self.settings, \
                                            self.discovery_addresses)
        return writer.write_to_file()

    def is_empty(self):
        if len(self.settings) == 0 and len(self.discovery_addresses) == 0:
            return True
        return False
        
class IscsidConfLinuxIscsi(IIscsidConf):
    def __init__(self, backup_path):
        self.backup_path = backup_path
        self.source_file = definitions.ISCSI_CONF_SOURCE
        self.set_dest_filename()
        self.load_config()

    def load_config(self):
        self.source_config = ConfigFileLinuxIscsi(\
            self.source_file, self.backup_path)
        self.dest_config = ConfigFileLinuxIscsi(\
            self.dest_filename, self.backup_path)
        self.source_config.read()
        self.dest_config.read()

    def set_dest_filename(self):
        self.dest_filename = '/etc/iscsi.conf'
